#
# spec file for package python-configshell
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define oname configshell

Name:           python-configshell
Summary:        A framework to implement simple but nice CLIs
License:        Apache-2.0
Group:          Development/Languages/Python
Version:        1.5
Release:        4.21
Url:            https://github.com/Datera/configshell
Source:         https://github.com/Datera/%{oname}/releases/download/%{version}/%{oname}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  epydoc
BuildRequires:  python-devel
BuildRequires:  python-pyparsing
Requires:       python-pyparsing
Requires:       python-urwid >= 0.9.9
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
A framework to implement simple but nice command-line interfaces.
ConfigShell Community Edition is a python library that provides a
framework for building simple but nice CLI-based applications.

For more information, see the configshell API reference, available in
both html and pdf formats as a separate package.

The latest version of this program might be obtained at:
http://www.risingtidesystems.com/git/

To run the example shell from this directory use: PYTHONPATH=.
./examples/myshell


%package doc
Summary:        A framework to implement simple but nice CLIs
License:        AGPL-3.0
Group:          Development/Languages/Python

%description doc
A framework to implement simple but nice command-line interfaces.
ConfigShell Community Edition is a python library that provides a
framework for building simple but nice CLI-based applications.

For more information, see the configshell API reference, available in
both html and pdf formats as a separate package.

The latest version of this program might be obtained at:
http://www.risingtidesystems.com/git/

To run the example shell from this directory use: PYTHONPATH=.
./examples/myshell



%prep
%setup -q -n %{oname}-%{version}

%build
%{__python} setup.py build
mkdir -p doc/
epydoc --no-sourcecode --html -n %{oname} --exclude configobj %{oname}/*.py
mv html doc/

%install
python setup.py install --skip-build --root %{buildroot} --prefix=%{_prefix}
mkdir -p %{buildroot}%{_defaultdocdir}/python-configshell
cp -r doc/* %{buildroot}%{_defaultdocdir}/python-configshell

%files
%defattr(-,root,root,-)
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc README.md COPYING
%dir %{_defaultdocdir}/python-configshell
%{_defaultdocdir}/python-configshell

%changelog
* Thu Nov 20 2014 lduncan@suse.com
- replaced "archive" source file with "release" bundle, same
  version. But this one shows version as "1.5" instead of "git"
  This replaced configshell-1.5.tar.bz2 with configshell-1.5.tar.gz
- updated spec file to point upstream, matching new gz file
* Mon May 19 2014 hare@suse.de
- Package COPYING and README.md
* Fri May 16 2014 hare@suse.de
- Update to version 1.5:
  * Update README
  * Build fixes
  * Ensure the first char of the version is a digit
  * Updated copyright notices to 2014
  * Debian packaging cleanup
  * Replace simpleparse with pyparsing
* Fri Dec 20 2013 p.drouand@gmail.com
- Fix Url
- Fix license; is Apache-2.0
* Wed Dec 18 2013 hare@suse.de
- Update to version 1.3:
  * Fix helptext - shell may not be interactive
  * Fix get_command_syntax bug
  * Allow mixed-case values for true/false
  * Don't use readline unless isatty
  * Do not print color escape codes if stdout is not a tty
  * Remove unused list_group_params arguments
  * Fixes list_group_params doc
  * Only return dict keys from list_config_groups
  * Make log warning color yellow
  * Improve ConfigNode._render_tree sorting
  * Fix debug log date format to YYYY-MM-DD
  * Avoid exception when arrowing down past end of list
  * Tagged version 1.3
- Removed patches merged into version 1.3:
  * 0001-Normalized-release-archive-generation.patch
  * 0002-Cleaned-up-packaging.patch
  * 0003-Fixed-HTML-documentation.patch
  * 0004-Removed-full-git-log-from-packages-changelogs.patch
  * 0005-Fixed-console-get_width.patch
  * 0006-Do-not-require-epydoc-at-runtime.patch
  * 0007-Fixes-agrover-Do-not-require-epydoc-patch
* Tue Dec 17 2013 hare@suse.de
- Update spec file after review
* Tue Dec 17 2013 hare@suse.de
- Import from SLES11 SP3, patches:
  * 0001-Normalized-release-archive-generation.patch:
    Normalized release archive generation
  * 0002-Cleaned-up-packaging.patch:
    Cleaned up packaging
  * 0003-Fixed-HTML-documentation.patch:
    Fixed HTML documentation
  * 0004-Removed-full-git-log-from-packages-changelogs.patch:
    Removed full git log from packages changelogs
  * 0005-Fixed-console-get_width.patch:
    Fixed console get_width()
  * 0006-Do-not-require-epydoc-at-runtime.patch:
    Do not require epydoc at runtime
  * 0007-Fixes-agrover-Do-not-require-epydoc-patch:
    Fixes agrover "Do not require epydoc" patch
* Mon Nov 25 2013 hare@suse.de
- Add epydoc to BuildRequires to avoid build failures
* Thu Nov  7 2013 hare@suse.de
- Remove epydoc dependency (bnc#828485)
* Mon Oct  1 2012 hare@suse.de
- Initial package, version 1.1
- Included patches from git tree, commit id d866b24
